@@ -91,6 +91,7 @@ class Device(Events):
     __serial_number = ""
     xml_string = ""
     __xpath_file = "./xpath_list.ini"
+    __environment_file = "./environment.ini"
     __screenshots = "./screenshots/"
     default_timeout = 30
     __syslog_output = False
@@ -405,6 +406,20 @@ class Device(Events):
         conf.read(self.__xpath_file)
         return conf.get(sop_id, key)
 
+    def get_environment(self, key: str, module: str = "General") -> str:
+        """
+        获取支撑脚本执行的环境变量，保存在脚本目录下的environment.ini文件中。\n
+        :param key: 键
+        :param module: 模块名称，默认值：General
+        :return: 环境变量值
+        """
+        if not os.path.exists(self.__environment_file):
+            f = open(self.__environment_file, "w")
+            f.close()
+        conf = configparser.ConfigParser()
+        conf.read(self.__environment_file)
+        return conf.get(module, key)
+
     def refresh_layout(self) -> None:
         """
         刷新当前设备的UI布局信息。\n
